@@ -44,7 +44,7 @@ KCompactDiscPrivate::KCompactDiscPrivate(KCompactDisc *p, const QString& dev) :
     m_trackExpectedPosition(0),
     m_seek(0),
 
-    m_randSequence(0),
+    m_randSequence(QRandomGenerator::global()->generate()),
     m_loopPlaylist(false),
     m_randomPlaylist(false),
     m_autoMetadata(true),
@@ -119,7 +119,7 @@ void KCompactDiscPrivate::make_playlist()
 	for(unsigned i = 0; i < size; ++i) {
 		if(m_randomPlaylist) {
 			do {
-				selected = 1 + m_randSequence.getLong(size);
+				selected = 1 + m_randSequence.bounded(size);
 				rejected = (m_playlist.indexOf(selected) != -1);
 			} while(rejected == true);
 		} else {
@@ -212,7 +212,7 @@ bool KCompactDiscPrivate::skipStatusChange(KCompactDisc::DiscStatus status)
 			}
 		}
 
-		emit q->discStatusChanged(status);
+		Q_EMIT q->discStatusChanged(status);
 	}
 
 	return false;
@@ -251,7 +251,7 @@ void KCompactDiscPrivate::clearDiscInfo()
 	m_trackArtists.clear();
 	m_trackTitles.clear();
 	m_trackStartFrames.clear();
-	emit q->discChanged(m_tracks);
+	Q_EMIT q->discChanged(m_tracks);
 }
 
 unsigned KCompactDiscPrivate::trackLength(unsigned)
@@ -305,5 +305,3 @@ unsigned KCompactDiscPrivate::balance()
 void KCompactDiscPrivate::queryMetadata()
 {
 }
-
-#include "kcompactdisc_p.moc"
